==> layoutstudio-7.x-1.6.tar.gz: layoutstudio/MYTHEME/template.php <==
<?php
// $Id:

/**
 * DEFAULTS CSS
 * Uncommenting the following lines will override the defaults.css
 * and default_ie.css in the LayoutStudio base theme, allowing you 
 * to user your own defaults/reset, or to simply remove them.
 * Make sure you add a default.css and defaults_ie.css in your theme,
 * even if it's an empty file.
 */
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/defaults.css', array('weight' => CSS_THEME, 'type' => 'file'));
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/defaults_ie.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'lt IE 9', '!IE' => FALSE), 'preprocess' => FALSE));

/**
 * Dedicated file to add @font-face
 */
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/fonts/fonts.css', array('weight' => CSS_THEME, 'type' => 'file'));

/**
 * Main Stylesheets
 */
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/all.css', array('weight' => CSS_THEME, 'type' => 'file'));
drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/screen.css', array('weight' => CSS_THEME, 'media' => 'screen, projection', 'type' => 'file'));
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/print.css', array('weight' => CSS_THEME, 'media' => 'print', 'type' => 'file'));

/**
 * IE Conditional Stylesheets
 */
drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/ie/fix-ie6.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'IE 6', '!IE' => FALSE), 'preprocess' => FALSE));
drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/ie/fix-ie7.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'IE 7', '!IE' => FALSE), 'preprocess' => FALSE));
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/ie/fix-ie8.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'IE 8', '!IE' => FALSE), 'preprocess' => FALSE));


/**
 * Override or insert variables into all templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered (name of the .tpl.php file.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the html templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_html(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the page templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
function MYTHEME_preprocess_page(&$variables) {
  // Add dimensions and other layout specific styles.
  $layout = theme_get_setting('layoutstudio_layout');
  $page_width = theme_get_setting('layoutstudio_page_width');
  $secondary_width = theme_get_setting('layoutstudio_secondary_width');
  $tertiary_width = theme_get_setting('layoutstudio_tertiary_width');
  $header_width = theme_get_setting('layoutstudio_header_width');
  $footer_width = theme_get_setting('layoutstudio_footer_width');
  
  // Width calculations for certain layouts
  if ($layout == "layout7") {
    $tertiary_width = $page_width - $secondary_width;
  }

	// Specify page width
	if ($header_width == 1 OR $footer_width == 1) {
		$data = '#container {width: '. $page_width .'px;}';
		if ($header_width == 1 && $footer_width == 1) {
			$data .= '#header .inside, #footer .inside {width: '. $page_width .'px; margin: 0 auto;}';
		}
		if ($header_width == 1 && $footer_width == 0) {
			$data .= '#header .inside {width: '. $page_width .'px; margin: 0 auto;}';
			$data .= '#footer {width: '. $page_width .'px; margin: 0 auto;}';
		}
		if ($header_width == 0 && $footer_width == 1) {
			$data .= '#footer .inside {width: '. $page_width .'px; margin: 0 auto;}';
			$data .= '#header {width: '. $page_width .'px; margin: 0 auto;}';
		}
	} 
	else {
		$data = '#page,#container {width: '. $page_width .'px;}';	
	}
	
	
	if ($layout != 'layout8') {
	
		if ($layout != 'layout7') {
      // Specify wrapper div settings
			$data .= '#wrapper {float: left; width: 100%;}';
		
		  // Specify primary div settings
			$data .= '#primary {';
	
      if ($layout == 'layout1') {
        $data .= '
          margin-left: '. $secondary_width .'px;
          margin-right: '. $tertiary_width .'px;
        ';
      }

      if ($layout == 'layout2') {
        $data .= '
          margin-left: '. $tertiary_width .'px;
          margin-right: '. $secondary_width .'px;
        ';
      }

      if ($layout == 'layout3' OR $layout == 'layout4') {
        $margin_right_width = $secondary_width + $tertiary_width;
        $data .= 'margin-right: '. $margin_right_width  .'px;';
      }

      if ($layout == 'layout5' OR $layout == 'layout6') {
        $margin_left_width = $secondary_width + $tertiary_width;
        $data .= 'margin-left: '. $margin_left_width  .'px;';
      }
	
			$data .= '}';		
		}
		
		// Specify secondary div settings
		$data .= '
			#secondary {
				float: left;
				width: '. $secondary_width .'px;
		';				

    if ($layout == 'layout1' OR $layout == 'layout5') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout == 'layout2' OR $layout == 'layout4') {
      $data .= 'margin-left: -'. $secondary_width .'px;';
    }
    if ($layout == 'layout3') {
      $margin_left_width = $secondary_width + $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout6') {
      $margin_left_width = $page_width - $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
		
		$data .= '}';		
	
		// Specify tertiary div settings
		$data .= '
			#tertiary {
				width: '. $tertiary_width .'px;
		';

    if ($layout == 'layout1' OR $layout == 'layout3') {
      $data .= 'margin-left: -'. $tertiary_width .'px;';
    }
    if ($layout == 'layout2') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout == 'layout4') {
      $margin_left_width = $secondary_width + $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout5') {
      $margin_left_width = $page_width - $secondary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout6') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout != 'layout7')	{
			$data .= 'float: left;';
		}
		if ($layout == 'layout7')	{
			$data .= 'float: right;';
		}
		
		$data .= '}';		
		
		// Specify adjustments on pages with no secondary content
		if (!$variables['page']['secondary_first'] && !$variables['page']['secondary'] && !$variables['page']['secondary_last']) {
			if ($layout == 'layout1') {
				$data .= '.no-secondary #primary {margin-left: 0;}';
			}	
			if ($layout == 'layout2') {
				$data .= '.no-secondary #primary {margin-right: 0;}';
			}	
			if ($layout == 'layout3' OR $layout == 'layout4') {
				$data .= '.no-secondary #primary {margin-right: '. $tertiary_width .'px;}';
			}	
			if ($layout == 'layout4') {
				$data .= '.no-secondary #tertiary {margin-left: -'. $tertiary_width .'px;}';
			}	
			if ($layout == 'layout5') {
				$data .= '.no-secondary #primary {margin-right: 0;}';
				$data .= '.no-secondary #primary {margin-left: '. $tertiary_width .'px;}';
			}	
			if ($layout == 'layout6' OR $layout == 'layout5') {
				$data .= '.no-secondary #tertiary {margin-left: -'. $page_width .'px;}';
			}	
			if ($layout == 'layout6') {
				$data .= '.no-secondary #primary {margin-left: '. $tertiary_width .'px;}';
			}	
			if ($layout == 'layout7') {
				$data .= '.no-secondary #tertiary {float: none; width: auto;}';
			}		
		}
	
		// Specify adjustments on pages with no tertiary content
		if (!$variables['page']['tertiary_first'] && !$variables['page']['tertiary'] && !$variables['page']['tertiary_last']) {
			if ($layout == 'layout1') {
				$data .= '.no-tertiary #primary {margin-right: 0;};';
				$margin_left_width = $page_width - $secondary_width;
				$data .= '.no-tertiary #secondary {margin-left: -'. $margin_left_width .'px;}';
			}	
			if ($layout == 'layout2') {
				$data .= '.no-tertiary #primary {margin-left: 0;};';
			}	
			if ($layout == 'layout3') {
				$data .= '.no-tertiary #primary {margin-right: '. $secondary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $secondary_width .'px;}';
			}	
			if ($layout == 'layout4') {
				$data .= '.no-tertiary #primary {margin-right: '. $tertiary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $tertiary_width .'px;}';
			}	
			if ($layout == 'layout5') {
				$data .= '.no-tertiary #primary {margin-left: '. $secondary_width .'px;}';
			}	
			if ($layout == 'layout6') {
				$data .= '.no-tertiary #primary {margin-left: '. $secondary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $page_width .'px;}';
			}	
			if ($layout == 'layout7') {
				$data .= '.no-tertiary #secondary {float: none; width: auto;}';
			}		
		}
		
		// Specify adjustments on pages with no secondary and no tertiary content
		if (!$variables['page']['secondary_first'] && !$variables['page']['secondary'] && !$variables['page']['secondary_last'] && !$variables['page']['tertiary_first'] && !$variables['page']['tertiary'] && !$variables['page']['tertiary_last']) {
			
			if ($layout == 'layout3' OR $layout == 'layout4' OR $layout == 'layout5') {
				$data .= '.no-secondary-and-tertiary #primary {margin-right: '. $tertiary_width .'px;};';
			}	
			if ($layout == 'layout4') {
				$data .= '.no-secondary-and-tertiary #tertiary {margin-left: -'. $tertiary_width .'px;};';
			}	
			if ($layout == 'layout5' OR $layout == 'layout6') {
				$data .= '.no-secondary-and-tertiary #tertiary {margin-left: -'. $page_width .'px;};';
			}	
			if ($layout == 'layout6') {
				$data .= '.no-secondary-and-tertiary #primary {margin-left: '. $tertiary_width .'px;};';
			}		
			
			if ($layout == 'layout1') {
				$margin_left_width = $page_width - $secondary_width;
				$data .= '.no-secondary-and-tertiary #secondary {margin-left: -'. $margin_left_width .'px;}';
			}	
			if ($layout == 'layout3') {
				$data .= '.no-secondary-and-tertiary #primary {margin-right: '. $secondary_width .'px;}';
				$data .= '.no-secondary-and-tertiary #secondary {margin-left: -'. $secondary_width .'px;}';
			}	
			if ($layout == 'layout4') {
				$data .= '.no-secondary-and-tertiary #primary {margin-right: '. $tertiary_width .'px;}';
				$data .= '.no-secondary-and-tertiary #secondary {margin-left: -'. $tertiary_width .'px;}';
			}	
			if ($layout == 'layout5') {
				$data .= '.no-secondary-and-tertiary #primary {margin-right: '. $secondary_width .'px;}';
			}	
			if ($layout == 'layout6') {
				$data .= '.no-secondary-and-tertiary #primary {margin-left: '. $secondary_width .'px;}';
				$data .= '.no-secondary-and-tertiary #secondary {margin-left: -'. $page_width .'px;}';
			}	
			
			if ($layout != 'layout7') {
				$data .= '.no-secondary-and-tertiary #wrapper {float: none; width: auto;}';
				$data .= '.no-secondary-and-tertiary #primary {margin: 0;}';
			}			
		}
	}

  drupal_add_css($data, array('type' => 'inline'));
}

/**
 * Implements hook_preprocess_maintenance_page().
 */
function MYTHEME_preprocess_maintenance_page(&$variables) {
  if (!$variables['db_is_active']) {
    $variables['site_name'] = '';
  }
  drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/maintenance-page.css');
}

/**
 * Override or insert variables into the node templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_node(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the comment templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_comment(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the block templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_block(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

==> layoutstudio-7.x-1.8.tar.gz: layoutstudio/MYTHEME/template.php <==
<?php
// $Id:

/**
 * DEFAULTS CSS
 * Uncommenting the following lines will override the defaults.css
 * and defaults_ie.css in the LayoutStudio base theme, allowing you
 * to user your own defaults/reset, or to simply remove them.
 * Make sure you add a defaults.css and defaults_ie.css in your theme,
 * even if it's an empty file.
 */
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/defaults.css', array('weight' => CSS_THEME, 'type' => 'file'));
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/defaults_ie.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'lt IE 9', '!IE' => FALSE), 'preprocess' => FALSE));

/**
 * Dedicated file to add @font-face
 */
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/fonts/fonts.css', array('weight' => CSS_THEME, 'type' => 'file'));

/**
 * Main Stylesheets
 */
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/all.css', array('weight' => CSS_THEME, 'type' => 'file'));
drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/screen.css', array('weight' => CSS_THEME, 'media' => 'screen, projection', 'type' => 'file'));
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/print.css', array('weight' => CSS_THEME, 'media' => 'print', 'type' => 'file'));

/**
 * IE Conditional Stylesheets
 */
drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/ie/fix-ie6.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'IE 6', '!IE' => FALSE), 'preprocess' => FALSE));
drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/ie/fix-ie7.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'IE 7', '!IE' => FALSE), 'preprocess' => FALSE));
//drupal_add_css(drupal_get_path('theme', 'MYTHEME') . '/css/ie/fix-ie8.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'IE 8', '!IE' => FALSE), 'preprocess' => FALSE));


/**
 * Override or insert variables into all templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered (name of the .tpl.php file.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the html templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_html(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the page templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_page(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the maintenance page template.
 * 
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_maintenance_page(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the node templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_node(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the comment templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_comment(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the block templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_block(&$variables) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */
